### Pixel Tool

The Pixel tool  (shortcut X, Shift-B if the Pencil tool is selected) draws pixel components.
Use the pixel tool to create pixel fonts and pixel symbols.

#### Setup

The Pixel tool requires a grid spacing of 2 or above.
Change it in “File” → “Font Info…” → “Other” → “Grid Spacing”.
See Grid Spacing & Subdivision for details.

The Pixel tool uses the glyph named “pixel” to draw pixels when clicking and dragging in Edit View.
If the glyph named pixel is not already in the font, Glyphs will offer to add it upon a click with the Pixel tool:

Click “Add” to create the pixel glyph.
By default, the pixel glyph is a square of the same size as the grid spacing.

#### Drawing Pixels

Select the Pixel tool, click once, and add a pixel component on the canvas.
Click again to remove the pixel.
Click and drag the mouse to add multiple pixels.
Start to drag on a pixel already in place to remove pixels while dragging.

#### Pixel Shape

The pixel glyph can be modified to contain any arbitrary shape.
Reduce the grid spacing to a lower number (for example, the default of 1) to draw path segments smaller than a pixel.
For instance, the pixel can be an x-mark  for a stitch effect.
Increase the grid spacing again when using the Pixel tool.